package com.sunrunaway.whipyou;

import java.io.IOException;

import android.app.Activity;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.util.Log;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.Toast;

//需要实现SensorEventListener接口
public class WhipYouActivity extends Activity implements SensorEventListener,
		OnCheckedChangeListener {

	private final static float ACC = 18;
	private CheckBox switchButton;

	private MediaPlayer mplayer;

	// 定义sensor管理器
	private SensorManager sensor;

	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		// 获取传感器管理服务
		sensor = (SensorManager) getSystemService(SENSOR_SERVICE);

		switchButton = (CheckBox) findViewById(R.id.checkBox1);
		switchButton.setOnCheckedChangeListener(this);

		mplayer = MediaPlayer.create(this, R.raw.whip8);
		try {
			mplayer.prepare();
			mplayer.setVolume(1.0f, 1.0f);
		} catch (IllegalStateException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		// mplayer.start();
	}

	@Override
	protected void onResume() {
		super.onResume();

		if (switchButton.isChecked()) {
			registerSenser();
		}

	}

	@Override
	protected void onStop() {
		unregisterSenser();
		if (mplayer != null) {
			mplayer.release();
		}
		super.onStop();
	}

	@Override
	protected void onPause() {
		if (switchButton.isChecked()) {
			unregisterSenser();
		}
		super.onPause();
	}

	@Override
	public void onAccuracyChanged(Sensor sensor, int accuracy) {
		// TODO Auto-generated method stub
		// 当传感器精度改变时回调该方法，Do nothing.
	}

	@Override
	public void onSensorChanged(SensorEvent event) {

		int sensorType = event.sensor.getType();

		// values[0]:X轴，values[1]：Y轴，values[2]：Z轴
		float[] values = event.values;

		if (sensorType == Sensor.TYPE_ACCELEROMETER) {

			/*
			 * 因为一般正常情况下，任意轴数值最大就在9.8~10之间，只有在你突然摇动手机的时候，瞬时加速度才会突然增大或减少。
			 * 所以，经过实际测试，只需监听任一轴的加速度大于14的时候，改变你需要的设置就OK了~~~
			 */
			if ((Math.abs(values[0]) > ACC || Math.abs(values[1]) > ACC || Math
					.abs(values[2]) > ACC)) {

				Log.i("sensor", "running");
				mplayer.start();

			}
		}
	}

	@Override
	public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
		if (isChecked) {
			registerSenser();
		} else {
			unregisterSenser();
		}

	}

	private void registerSenser() {
		boolean done;
		done = sensor.registerListener(this,
				sensor.getDefaultSensor(Sensor.TYPE_ACCELEROMETER),
				// 还有SENSOR_DELAY_UI、SENSOR_DELAY_FASTEST、SENSOR_DELAY_GAME等，
				// 根据不同应用，需要的反应速率不同，具体根据实际情况设定
				SensorManager.SENSOR_DELAY_NORMAL);
		if (!done) {
			Toast.makeText(this,
					getResources().getString(R.string.sensor_unsupported),
					Toast.LENGTH_SHORT).show();
			switchButton.setChecked(false);
		}
		Log.i("sensor", "register");
	}

	private void unregisterSenser() {
		sensor.unregisterListener(this);
		Log.i("sensor", "unregister");
	}

}